import 'terminal.dart';
import 'option.dart';

final _terminal = const Terminal();

class Prompter {
  const Prompter();

  bool askBinary(String question, [void Function() preAskFunc = null]) {
    final userInput = this._ask("$question (y/n)", preAskFunc: preAskFunc);
    if (userInput.toLowerCase() == 'y' || userInput.toLowerCase() == 'n') {
      return userInput.toLowerCase() == 'y';
    }

    return this.askBinary(question, () {
      _terminal.printPrompt('invalid selection, please anwser again');
      _terminal.printPrompt();
    });
  }

  askMultiple(String question, List<Option> options,
      [void Function() preAskFunc = null]) {
    final userInput =
        this._ask(question, options: options, preAskFunc: preAskFunc);
    try {
      return options[int.parse(userInput)].value;
    } catch (e) {
      return this.askMultiple(question, options, () {
        _terminal.printPrompt('invalid selection, please select again');
        _terminal.printPrompt();
      });
    }
  }

  String _ask(String question,
      {List<Option> options = const [], void Function() preAskFunc = null}) {
    _terminal.clearScreen();
    if (preAskFunc != null) {
      preAskFunc();
    }
    _terminal.printPrompt(question);
    _terminal.printOptions(options);
    return _terminal.collectInput();
  }
}
